---
name: Feature request
about: Suggest an idea for this project
title: ''
labels: enhancement
assignees: ''

---

**Describe the feature**
A clear and concise description of the feature you are requesting.

**A use case for the feature**
A description of a real world scenario for the feature (if applicable).

**Would you like to be involved in development?**
If yes, please specify how, and how to contact you.

**Additional context**
Add any other context about the feature request here.
